@@ -26,7 +26,7 @@
 #include <obgnome/obgnomePropertyBox.h>
 #include <obgnome/obgnomeRootWin.h>
 #include <obgnome/obgnomeStockButton.h>
-#include <obgnome/obgnomeStockPixmapWidget.h>
+#include <obgnome/obgnomeStock.h>
 #include <obgnome/obgnomeTTY.h>
 #include <obgnome/obgnomeTerm.h>
 #include <obgnome/obgnomeVtEmu.h>
