@@ -4,7 +4,7 @@ static void
 obgnome_do_signal_connection(GnomeApp *app,
 			     GnomeUIInfo *info_item,
 			     gchar *signal_name,
-			     GnomeUIBuilderData uidata)
+			     GnomeUIBuilderData *uidata)
 {
   /* Copied almost verbatrim from obgtk/obgtkObject.m - connectObj */
   gchar *datid;
