@@ -12,7 +12,7 @@
        :(guint) max_width
        :(guint) scrollback
 {
-  gtk_term_setup(gtkterm, width, height, max_width, scrollback);
+  gtk_term_construct(gtkterm, width, height, max_width, scrollback);
   return self;
 }
 
