@@ -20,6 +20,7 @@
 	    :(GtkPolicyType) hscrollbar_policy;
 - freeze;
 - thaw;
+
 - set_column_title:(gint) column
 		  :(gchar *) title;
 - set_column_widget:(gint) column
@@ -91,6 +92,11 @@
 - (gint) get_selection_info:(gint) x :(gint) y
 		     getRow:(gint *) row
 		  getColumn:(gint *) column;
+
+- undo_selection;
+- select_all;
+- unselect_all;
+- swap_rows:(gint) row1 :(gint) row2;
 @end
 
 #endif /* OBGTK_CLIST_H */
