@@ -283,4 +283,28 @@
 {
   return gtk_clist_find_row_from_data(gtkclist, data);
 }
+
+- undo_selection
+{
+  gtk_clist_undo_selection(gtkclist);
+  return self;
+}
+
+- select_all
+{
+  gtk_clist_select_all(gtkclist);
+  return self;
+}
+
+- unselect_all
+{
+  gtk_clist_unselect_all(gtkclist);
+  return self;
+}
+
+- swap_rows:(gint) row1 :(gint) row2
+{
+  gtk_clist_swap_rows(gtkclist, row1, row2);
+  return self;
+}
 @end
