@@ -12,17 +12,20 @@
 
 - castGtkContainer:(GtkContainer *) castitem;
 - border_width:(gint) width;
-- add:(Gtk_Widget *) widget;
-- remove:(Gtk_Widget *) widget;
+- add:(id) widget;
+- remove:(id) widget;
 - disable_resize;
 - enable_resize;
 - block_resize;
 - unblock_resize;
-- need_resize;
-- foreach    : callback:(GtkCallback) acallback
- callbackData:(gpointer) callback_data;
+- (gint)need_resize;
+- foreach    : callbackFunction:(GtkCallback) acallback
+callbackData:(gpointer) callback_data;
+- foreach_method:(SEL) method; /* this method should take no explicit arguments */
 - focus:(GtkDirectionType) direction;
-- (GList *) children;
+- (GList *) children; /* a GList of GtkWidget *'s, NOT object id's */
+- register_toplevel;
+- unregister_toplevel;
 @end
 
 #endif /* OBGTK_CONTAINER_H */
