@@ -1,4 +1,7 @@
-#include "obgtk.h"
+#include "obgtkDialog.h"
+#include "obgtkHBox.h"
+#include "obgtkVBox.h"
+#include <gtk/gtk.h>
 
 @implementation Gtk_Dialog
 - init
@@ -8,9 +11,12 @@
 
 - castGtkDialog:(GtkDialog *)castitem
 {
+  self = [super castGtkWindow:GTK_WINDOW(castitem)];
   gtkdialog = GTK_DIALOG(castitem);
+
   vbox = [[Gtk_VBox alloc] castGtkVBox:GTK_VBOX(gtkdialog->vbox)];
   action_area = [[Gtk_HBox alloc] castGtkHBox:GTK_HBOX(gtkdialog->action_area)];
-  return [super castGtkWindow:GTK_WINDOW(gtkdialog)];  
+
+  return self;
 }
 @end
