@@ -9,12 +9,11 @@
 @public
   GtkHButtonBox *gtkhbuttonbox;
 }
-- init;
 - castGtkHButtonBox:(GtkHButtonBox *) castitem;
 - (gint) get_spacing_default;
-- (gint) get_layout_default;
+- (GtkButtonBoxStyle) get_layout_default;
 - set_spacing_default:(gint) spacing;
-- set_layout_default:(gint) layout;
+- set_layout_default:(GtkButtonBoxStyle) layout;
 @end
 
 #endif /* OBGTK_HBUTTON_BOX_H */
