@@ -9,6 +9,6 @@
 - castGtkHandleBox:(GtkHandleBox *) castitem
 {
   gtkhandlebox = castitem;
-  return [super castGtkEventBox:GTK_EVENT_BOX(castitem)];
+  return [super castGtkBin:GTK_BIN(castitem)];
 }
 @end
