@@ -1,10 +1,11 @@
-#include "obgtk.h"
+#include "obgtkLabel.h"
 
 @implementation Gtk_Label
 - castGtkLabel:(GtkLabel *) castitem
 {
+  self = [super castGtkMisc:GTK_MISC(castitem)];
   gtklabel = GTK_LABEL(castitem);
-  return [super castGtkMisc:GTK_MISC(castitem)];
+  return self;
 }
 
 - init
