@@ -15,8 +15,10 @@
 - initWithLabel:(gchar *) label;
 - set_submenu:(id) submenu;
 - set_placement:(GtkSubmenuPlacement) placement;
+#ifndef GTK_HAVE_FEATURES_1_1_0
 - accelerator_size;
 - accelerator_text:(gchar *)buffer;
+#endif
 - configure     :(gint)show_toggle_indicator
  indicateSubmenu:(gint)show_submenu_indicator;
 - select;
