@@ -30,6 +30,7 @@
   return self;
 }
 
+#ifndef GTK_HAVE_FEATURES_1_1_0
 - accelerator_size
 {
   gtk_menu_item_accelerator_size(gtkmenuitem);
@@ -41,6 +42,7 @@
   gtk_menu_item_accelerator_text(gtkmenuitem, buffer);
   return self;
 }
+#endif
 
 - configure     :(gint)show_toggle_indicator
  indicateSubmenu:(gint)show_submenu_indicator
