@@ -5,6 +5,14 @@
 #include <gtk/gtksignal.h>
 #include <gtk/gtkobject.h>
 
+extern guint obgtk_objc_id_key;
+extern inline guint OBJC_ID(void)
+{
+  if(!obgtk_objc_id_key)
+    obgtk_objc_id_key = gtk_object_data_force_id("objc_id");
+  return obgtk_objc_id_key;
+}
+
 struct _ObgtkRelayInfo {
   id object;
   SEL method;
@@ -19,16 +27,18 @@ obgtk_signal_relay(GtkObject *object,
 		   GtkArg *args);
 
 /* You can pass this in as a GtkSignalFunc and have the data be
-   the name of the method to call... However it's not perfect */
-gint
+   the selector of the method to call... However it's not perfect */
+gpointer
 obgtk_callback_relay(GtkObject *object,
 		     gpointer data);
 
 @interface Gtk_Object : Object
 {
+  guint destroy_handler_id;
 @public
-    GtkObject *gtkobject;
+  GtkObject *gtkobject;
 }
+- (GtkObject *)getGtkObject;
 - castGtkObject:(GtkObject *)castitem;
 - set_user_data:(gpointer) thedata;
 - (gpointer)get_user_data;
@@ -55,8 +65,20 @@ obgtk_callback_relay(GtkObject *object,
 - connectObj:(gchar *) signal_name
 	    :(id) signalObject;
 
+- connectObjMethod:(gchar *) signal_name
+		  :(id) signalObject
+		  :(SEL) method;
+
+/* A little more freedom here (don't want to break old interfaces :-) */
+- connectObj2:(gchar *) signal_name
+	     :(id) signalObject
+	     :(guint *) ret_handler_id
+	     :(SEL) method;
 - ref;
 - unref;
+
+- sink;
+- destroy;
 @end
 
 #endif /* OBGTK_OBJECT_H */
