@@ -1,4 +1,4 @@
-#include "obgtk.h"
+#include "obgtkRange.h"
 
 @implementation Gtk_Range
 - castGtkRange:(GtkRange *) castitem
@@ -68,4 +68,44 @@
   return self;
 }
 
+- default_hslider_update
+{
+  gtk_range_default_hslider_update(gtkrange);
+  return self;
+}
+
+- default_vslider_update
+{
+  gtk_range_default_vslider_update(gtkrange);
+  return self;
+}
+
+- default_htrough_click:(gint) x
+		       :(gint) y
+		       :(gfloat *) jump_perc
+{
+  gtk_range_default_htrough_click(gtkrange, x, y, jump_perc);
+  return self;
+}
+
+- default_vtrough_click:(gint) x
+		       :(gint) y
+		       :(gfloat *) jump_perc
+{
+  gtk_range_default_vtrough_click(gtkrange, x, y, jump_perc);
+  return self;
+}
+
+- default_hmotion:(gint) xdelta
+		 :(gint) ydelta
+{
+  gtk_range_default_hmotion(gtkrange, xdelta, ydelta);
+}
+
+- default_vmotion:(gint) xdelta
+		 :(gint) ydelta
+{
+  gtk_range_default_vmotion(gtkrange, xdelta, ydelta);
+  return self;
+}
 @end
