@@ -11,15 +11,18 @@
    GtkSpinButton *gtkspinbutton;
 }
 - castGtkSpinButton:(GtkSpinButton *) castitem;
-- initWithSpinInfo:(Gtk_Adjustment *) adjustment
+- initWithSpinInfo:(id) adjustment
 		  :(gfloat) climb_rate
 		  :(gint) digits;
-- set_adjustment:(Gtk_Adjustment *) adjustment;
+- set_adjustment:(id) adjustment;
 - (id) get_adjustment;
 - set_digits:(gint) digits;
 - (gfloat) get_value_as_float;
 - (gint) get_value_as_int;
 - set_value:(gfloat) value;
 - set_update_policy:(GtkSpinButtonUpdatePolicy) policy;
+- set_numeric:(gint) numeric;
+- spin:(guint) direction :(gfloat) step;
+- set_wrap:(gint) wrap;
 @end
 #endif
