@@ -11,11 +11,11 @@
   GtkText *gtktext;
 }
 - castGtkText:(GtkText *) castitem;
-- initWithAdjustments:(Gtk_Adjustment *) hadjustment
-		 adjV:(Gtk_Adjustment *) vadjustment;
+- initWithAdjustments:(id) hadjustment
+		 adjV:(id) vadjustment;
 - set_editable:(gint) editable;
-- set_adjustments:(Gtk_Adjustment *) hadjustment
-	     adjV:(Gtk_Adjustment *) vadjustment;
+- set_adjustments:(id) hadjustment
+	     adjV:(id) vadjustment;
 - set_point:(gint) index;
 - (guint) get_point;
 - (guint) get_length;
@@ -28,6 +28,8 @@
    insLen:(gint) length;
 - (gint) backward_delete:(guint) nchars;
 - (gint) forward_delete:(guint) nchars;
+
+- set_word_wrap:(gint) word_wrap;
 @end
 
 #endif /* OBGTK_TEXT_H */
