@@ -4,7 +4,7 @@
 #include <objc/Object.h>
 #include <obgtk/obgtkWidget.h>
 #include <obgtk/obgtkData.h>
-#include <gtk/gtktooltips.h>
+#include <gtk/gtk.h>
 
 @interface Gtk_Tooltips : Gtk_Data
 {
@@ -12,9 +12,9 @@
   GtkTooltips *gtktooltips;
 }
 - castGtkTooltips:(GtkTooltips *) castitem;
-- init;
 - initWithGtkWidgetLabel:(Gtk_Widget *)widget
-		tipsText:(gchar *) tips_text;
+		tipsText:(gchar *) tips_text
+	     tipsPrivate:(gchar *) tips_private;
 - enable;
 - disable;
 - set_delay:(gint) delay;
@@ -22,7 +22,7 @@
   tipsText:(gchar *) tips_text
   tipsPrivate:(gchar *) tips_private;
 - set_colors:(GdkColor *) background
-   colorFg:(GdkColor *) foreground;
+     colorFg:(GdkColor *) foreground;
 @end
 
 #endif /* OBGTK_TOOLTIPS_H */
