@@ -6,7 +6,7 @@
 #include <gtk/gtkvscale.h>
 
 @interface Gtk_VScale : Gtk_Scale
-- initWithGtkAdjustment:(Gtk_Adjustment *) adjustment;
+- initWithGtkAdjustment:(id) adjustment;
 @end
 
 #endif /* OBGTK_VSCALE_H */
